﻿-- Localisation strings for Excavatinator

local function copyTable(tbl)
	if type(tbl) ~= "table" then return tbl end
	local r = {}
	for k,v in pairs(tbl) do
		r[k] = copyTable(v)
	end
	setmetatable(r, getmetatable(tbl))
	return r
end

local L = {
	enGB = {
		-- Errors
		["This update to Excavatinator requires a client restart."] = "This update to Excavatinator requires a client restart.", -- This error will be displayed in English regardless; the localisation table is loaded after the version check.
		-- Race frame
		["Race"] = "Race",
		["Progress"] = "Progress",
		["Artifact"] = "Artifact",
		["Keystones"] = "Keystones",
		["Project"] = "Project",
		["Item"] = "Item",
		["Total:"] = "Total:",
		["Common:"] = "Common:",
		["Rare:"] = "Rare:",
		["Skill:"] = "Skill:",
		["%d / %d artifacts completed."] = "%d / %d artifacts completed.",
		["%d solves total."] = "%d solves total.",
		["%s / %d fragments"] = "%s / %d fragments",
		["Ready to solve."] = "Ready to solve.",
		["Need %d more."] = "Need %d more.",
		["Click to open artifact list."] = "Click to open artifact list.",
		["Right click to solve artifact."] = "Right click to solve artifact.",
		["Your archaeology skill is nearly at your skill cap! Visit a trainer soon."] = "Your archaeology skill is nearly at your skill cap! Visit a trainer soon.",
		-- List frame
		["RARE ARTIFACTS"] = "RARE ARTIFACTS",
		["COMMON ARTIFACTS"] = "COMMON ARTIFACTS",
		["OTHER"] = "OTHER",
		["[Completed]"] = "[Completed]",
		["[%d Completed]"] = "[%d Completed]",
		["[Incomplete]"] = "[Incomplete]",
		["[Unknown]"] = "[Unknown]",
		["MISSING RARE ARTIFACTS"] = "MISSING RARE ARTIFACTS",
		["COMPLETED RARE ARTIFACTS"] = "COMPLETED RARE ARTIFACTS",
		["MISSING COMMON ARTIFACTS"] = "MISSING COMMON ARTIFACTS",
		["COMPLETED COMMON ARTIFACTS"] = "COMPLETED COMMON ARTIFACTS",
		-- Achievement frame
		["You have completed this achievement!"] = "You have completed this achievement!",
		["You need %d more artifacts."] = "You need %d more artifacts.",
		["Click here for a list of undiscovered common artifacts."] = "Click here for a list of undiscovered common artifacts.",
		["Click here for a list of undiscovered rare artifacts."] = "Click here for a list of undiscovered rare artifacts.",
		["You still need artifacts from this race:"] = "You still need artifacts from this race:",
		["You still need artifacts from these %d races:"] = "You still need artifacts from these %d races:",
		["Requires %d skill points."] = "Requires %d skill points.",
		["You still need the following %d artifacts:"] = "You still need the following %d artifacts:",
		["You still need the following %d %s artifacts:"] = "You still need the following %d %s artifacts:", -- Note: %s is the race, ex: "You still need the following 4 night elf artifacts"
		["You still need %d skill points in archaeology."] = "You still need %d skill points in archaeology.",
		-- Links frame
		["<none selected>"] = "<none selected>",
		["OK"] = "OK",
		["Cancel"] = "Cancel",
		["Delete the link between \"%s\" and \"%s\"?"] = "Delete the link between \"%s\" and \"%s\"?",
		["Create a link between \"%s\" and \"%s\"?"] = "Create a link between \"%s\" and \"%s\"?",
		-- Options frame
		["Show finds on minimap"] = "Show finds on minimap",
		["Track finds"] = "Track finds",
		["Import data from:"] = "Import data from:",
		["Database sharing:"] = "Database sharing:",
		["Broadcasts"] = "Broadcasts",
		["Guild"] = "Guild",
		["Player"] = "Player",
		["Add"] = "Add",
		["Transfer"] = "Transfer",
		["Send"] = "Send",
		["Get"] = "Get",
		-- Minimap tracker
		["Are you sure you want to clear your node database? This can NOT be undone."] = "Are you sure you want to clear your node database? This can NOT be undone.",
		["Import node data from Archy?"] = "Import node data from Archy?",
		["%s is requesting that you share your node database with them. Accept?"] = "%s is requesting that you share your node database with them. Accept?",
		["%s is offering to share their node database. Accept?"] = "%s is offering to share their node database. Accept?",
		["Send a database transfer request to %s?"] = "Send a database transfer request to %s?",
		["Offer to share your database with %s?"] = "Offer to share your database with %s?",
		["%s has denied your request."] = "%s has denied your request.",
		["%s is busy."] = "%s is busy.",
		["You are busy."] = "You are busy.",
		["Your transfer has timed out."] = "Your transfer has timed out.",
		["Yes"] = "Yes",
		["No"] = "No",
		["OK"] = "OK",
		["Request sent to %s"] = "Request sent to %s",
		["Offer sent to %s"] = "Offer sent to %s",
		["Request from %s"] = "Request from %s",
		["Offer from %s"] = "Offer from %s",
		["Getting data from %s"] = "Getting data from %s",
		["Sending data to %s"] = "Sending data to %s",
		-- Tooltip info
		TRAVELFRAME_TITLE = "Travel frame",
		TRAVELFRAME_TEXT = "Click to open a list of any instant-travel items\nor abilities you have.",
		ITEMSFRAME_TITLE = "Items frame",
		ITEMSFRAME_TEXT = "Click to open a list of any archaeology\non-use items you have.",
		ACHIEVEMENTFRAME_TITLE = "Achievement tracker",
		ACHIEVEMENTFRAME_TEXT = "The achievement tracker provides you with\ninformation about the archaeology achievements\nand your progress for them.",
		OPTIONSFRAME_TITLE = "Options frame",
		OPTIONSFRAME_TEXT = "Click to open the options frame.",
		LINKSFRAME_TITLE = "Links frame",
		LINKSFRAME_TEXT = "Click to open the links frame.\nHere you can manually link an archaeology project\nto the item it creates, if Excavatinator could\nnot do it automatically. You can also delete any\nexisting links, should you choose to.",
		DBFRAME_TITLE = "Database frame",
		DBFRAME_TEXT = "The database frame holds the controls for your\ndatabase, and whether and how it's shared.",
		RESETDB_TITLE = "Reset the node database.",
		RESETDB_TEXT = "This will clear all the nodes in your database.\nOnce deleted, the information can not be restored.",
		BROADCASTS_TITLE = "Broadcast settings",
		BROADCASTS_TEXT = "Add or remove players from your broadcast list.\nWhen you find a fragment, players on this list\nwill have it added to their database, if they\nhave listed you as well.",
		TRANSFER_TITLE = "Transfer database",
		TRANSFER_TEXT = "Here you can request a copy of another player's node\ndatabase, or offer to share yours with them.",
	},
}

L.metatable = {
	__index = function()
		return L.enGB
	end,
	subtable = {
		__index = function(tbl, key)
			if type(rawget(L.enGB, key)) == "table" then
				return rawget(L.enGB, key) -- If a tooltip table is requested but not found, return the English value rather than the key.
			end
			return key
		end,
	},
}

setmetatable(L, L.metatable)
for k,v in pairs(L) do
	setmetatable(v, L.metatable.subtable)
end


function Excavatinator:GetLocale()
	local locale = GetLocale()
	for k,v in pairs(L) do -- Any non-current locale, apart from the English one, is now garbage; get rid of it.
		if k ~= locale and k~= "enGB" then
--			table.wipe(v)
			L[k] = nil
		end
	end
	return copyTable(L[locale])
end